#!/bin/sh
# Copyright (C) 2000-2011 Synology Inc. All rights reserved.
VERSION=1.0-006
TarFileName="SSWatermark-${VERSION}.tar.gz"
DestDirName="SSWatermark"
ReadLink=/bin/readlink

YNConfirm() {
	read YN
	if [ "x$YN" = "xY" -o "x$YN" = "xy" ]; then
		return
	else
		exit 0
	fi
}

CheckIfNeedIA32Libs() {

	isUbuntuLinux=`uname -a | grep -ic "Ubuntu"`
	Arch=`uname -m`
	isIa32LibInstall=`dpkg --get-selections | grep -ic "ia32-libs[[:space:]]*install"`
	if [ "${isUbuntuLinux}" != "0" ]; then

		if [ "${Arch}" = "x86_64" -a "${isIa32LibInstall}" = "0" ]; then
				cat << EOF

Package [ia32-libs] is required to run Synology Watermark.
Root privilege is required to install the package.
Would you want to install package [ia32-libs] now? [Y/n]:
EOF
		fi
	fi

	read ANS
	if [ "x$ANS" = "xN" -o "x$ANS" = "xn" ]; then
		exit 0
	else
		sudo apt-get install ia32-libs
	fi

}

if [ ! -f ./${TarFileName} ]; then
	echo "File [${TarFileName}] not found."
	exit 255
fi

cat << EOF
This script will install Synology Watermark version ${VERSION} to your system.
Are you sure you want to continue? [y/N]
EOF
YNConfirm

CleanInstall() {
	cat << EOF

Please input the install path for Synology Watermark,
Input empty path or [.] will install to current directory.
EOF
	read InstallPath

	if [ -z "${InstallPath}" ]; then
		InstallPath=`pwd`
	elif [ ! -d "${InstallPath}" ]; then
		mkdir -p ${InstallPath}
		if [ $? -ne 0 ]; then
			cat << EOF

Fail to create this directory [${InstallPath}]
Are you want to create by sudo? [y/N]
EOF
			YNConfirm
			sudo mkdir -p ${InstallPath}
		fi
	fi
	cat << EOF

Try to install Synology Watermark to [${InstallPath}/${DestDirName}] ...
Are you sure you want to continue? [y/N]
EOF
	YNConfirm

	CheckIfNeedIA32Libs

	tar zxvf ${TarFileName} -C "${InstallPath}"
	if [ $? -ne 0 ]; then
		cat << EOF

Fail to untar to this directory [${InstallPath}]
Are you want to create by sudo? [y/N]
EOF
		YNConfirm
		sudo tar zxvf ${TarFileName} -C "${InstallPath}"
	fi
}

CreateSymbolLink() {
	sudo rm -f /usr/local/bin/SSWatermark
	sudo ln -sf ${InstallPath}/SSWatermark/SSWatermark /usr/local/bin/SSWatermark
}

TestSymbolLinkTarget() {
	RetSymbolic=0
	if [ ! -L /usr/local/bin/SSWatermark ]; then
		RetSymbolic=1
	else
		LinkTarget=`$ReadLink /usr/local/bin/SSWatermark`
		if [ "$LinkTarget" != "${InstallPath}/SSWatermark/SSWatermark" ]; then
			RetSymbolic=1
		fi
	fi
	return ${RetSymbolic}
}

CleanInstall

cat << EOF

Now you can run Synology Watermark from
${InstallPath}/SSWatermark/SSWatermark 
EOF

id | grep "uid=0" >/dev/null
if [ $? -eq 0 ]; then
	TestSymbolLinkTarget
	BuildSymbolic=$?

	if [ "${BuildSymbolic}" = 1 ]; then
		cat << EOF

Would you want to create a symbolic link [/usr/local/bin/SSWatermark] 
to [${InstallPath}/SSWatermark]? 
[y/N]
EOF
		YNConfirm
		CreateSymbolLink
	fi
fi

	TestSymbolLinkTarget
	BuildSymbolic=$?

if [ "${BuildSymbolic}" = 1 ]; then
	cat << EOF

Or you can create a symbolic link 
[/usr/local/bin/SSWatermark] to [${InstallPath}/SSWatermark] by
\$ sudo ln -sf ${InstallPath}/SSWatermark/SSWatermark \
/usr/local/bin/SSWatermark
and run 
/usr/local/bin/SSWatermark

EOF
else
	cat << EOF

Or you can run through the symbolic link [/usr/local/bin/SSWatermark]
EOF
fi
